@@ -99,23 +99,23 @@ void KrBriefView::setup() {
    // decide on single click/double click selection
    if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) &&
            TDEGlobalSettings::singleClick() ) {
-      connect( this, TQT_SIGNAL( executed( TQIconViewItem* ) ), this, TQT_SLOT( slotExecuted( TQIconViewItem* ) ) );
+      connect( this, TQ_SIGNAL( executed( TQIconViewItem* ) ), this, TQ_SLOT( slotExecuted( TQIconViewItem* ) ) );
    } else {
-      connect( this, TQT_SIGNAL( clicked( TQIconViewItem* ) ), this, TQT_SLOT( slotClicked( TQIconViewItem* ) ) );
-      connect( this, TQT_SIGNAL( doubleClicked( TQIconViewItem* ) ), this, TQT_SLOT( slotDoubleClicked( TQIconViewItem* ) ) );
+      connect( this, TQ_SIGNAL( clicked( TQIconViewItem* ) ), this, TQ_SLOT( slotClicked( TQIconViewItem* ) ) );
+      connect( this, TQ_SIGNAL( doubleClicked( TQIconViewItem* ) ), this, TQ_SLOT( slotDoubleClicked( TQIconViewItem* ) ) );
    }
 
    // a change in the selection needs to update totals
-   connect( this, TQT_SIGNAL( onItem( TQIconViewItem* ) ), this, TQT_SLOT( slotItemDescription( TQIconViewItem* ) ) );
-   connect( this, TQT_SIGNAL( contextMenuRequested( TQIconViewItem*, const TQPoint& ) ),
-            this, TQT_SLOT( handleContextMenu( TQIconViewItem*, const TQPoint& ) ) );
-	connect( this, TQT_SIGNAL( rightButtonPressed(TQIconViewItem*, const TQPoint&)),
-		this, TQT_SLOT(slotRightButtonPressed(TQIconViewItem*, const TQPoint&)));
-   connect( this, TQT_SIGNAL( currentChanged( TQIconViewItem* ) ), this, TQT_SLOT( setNameToMakeCurrent( TQIconViewItem* ) ) );
-   connect( this, TQT_SIGNAL( currentChanged( TQIconViewItem* ) ), this, TQT_SLOT( transformCurrentChanged( TQIconViewItem* ) ) );
-   connect( this, TQT_SIGNAL( mouseButtonClicked ( int, TQIconViewItem *, const TQPoint & ) ),
-            this, TQT_SLOT( slotMouseClicked ( int, TQIconViewItem *, const TQPoint & ) ) );
-   connect( &KrColorCache::getColorCache(), TQT_SIGNAL( colorsRefreshed() ), this, TQT_SLOT( refreshColors() ) );
+   connect( this, TQ_SIGNAL( onItem( TQIconViewItem* ) ), this, TQ_SLOT( slotItemDescription( TQIconViewItem* ) ) );
+   connect( this, TQ_SIGNAL( contextMenuRequested( TQIconViewItem*, const TQPoint& ) ),
+            this, TQ_SLOT( handleContextMenu( TQIconViewItem*, const TQPoint& ) ) );
+	connect( this, TQ_SIGNAL( rightButtonPressed(TQIconViewItem*, const TQPoint&)),
+		this, TQ_SLOT(slotRightButtonPressed(TQIconViewItem*, const TQPoint&)));
+   connect( this, TQ_SIGNAL( currentChanged( TQIconViewItem* ) ), this, TQ_SLOT( setNameToMakeCurrent( TQIconViewItem* ) ) );
+   connect( this, TQ_SIGNAL( currentChanged( TQIconViewItem* ) ), this, TQ_SLOT( transformCurrentChanged( TQIconViewItem* ) ) );
+   connect( this, TQ_SIGNAL( mouseButtonClicked ( int, TQIconViewItem *, const TQPoint & ) ),
+            this, TQ_SLOT( slotMouseClicked ( int, TQIconViewItem *, const TQPoint & ) ) );
+   connect( &KrColorCache::getColorCache(), TQ_SIGNAL( colorsRefreshed() ), this, TQ_SLOT( refreshColors() ) );
 
    // add whatever columns are needed to the listview
    krConfig->setGroup( nameInTDEConfig() );
@@ -131,10 +131,10 @@ void KrBriefView::setup() {
 
    // allow in-place renaming
 
-   connect( this, TQT_SIGNAL( itemRenamed ( TQIconViewItem * ) ),
-            this, TQT_SLOT( inplaceRenameFinished( TQIconViewItem * ) ) );
-   connect( &renameTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( renameCurrentItem() ) );
-   connect( &contextMenuTimer, TQT_SIGNAL (timeout()), this, TQT_SLOT (showContextMenu()));
+   connect( this, TQ_SIGNAL( itemRenamed ( TQIconViewItem * ) ),
+            this, TQ_SLOT( inplaceRenameFinished( TQIconViewItem * ) ) );
+   connect( &renameTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( renameCurrentItem() ) );
+   connect( &contextMenuTimer, TQ_SIGNAL (timeout()), this, TQ_SLOT (showContextMenu()));
 
    setSelectionMode( TQIconView::Extended );
 
@@ -152,7 +152,7 @@ void KrBriefView::setup() {
    header->setStretchEnabled( true );
 
    header->setSortIndicator( 0, sortDirection() ? TQt::Ascending : TQt::Descending );
-   connect( header, TQT_SIGNAL(clicked( int )), this, TQT_SLOT( changeSortOrder()));
+   connect( header, TQ_SIGNAL(clicked( int )), this, TQ_SLOT( changeSortOrder()));
 
    header->installEventFilter( this );
    header->show();
@@ -189,7 +189,7 @@ void KrBriefView::redrawColumns()
 
    setGridX( width() / PROPS->numberOfColumns );
 
-   // QT bug, it's important for recalculating the bounding rectangle
+   // TQt bug, it's important for recalculating the bounding rectangle
    for( TQIconViewItem * item = firstItem(); item; item = item->nextItem() )
    {
       TQString txt = item->text();
@@ -443,7 +443,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
 
    TQIconViewItem * oldCurrent = currentItem();
    TQIconViewItem *newCurrent = findItem( e->pos() );
-   if (e->button() == Qt::RightButton)
+   if (e->button() == TQt::RightButton)
    {
 	if (KrSelectionMode::getSelectionHandler()->rightButtonSelects() ||
 		(((e->state() & ShiftButton) || (e->state() & ControlButton))) && KrSelectionMode::getSelectionHandler()->shiftCtrlRightButtonSelects())
@@ -501,7 +501,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
        e->accept();
      }
    }
-   if (e->button() == Qt::LeftButton)
+   if (e->button() == TQt::LeftButton)
    {
      dragStartPos = e->pos();
 	  if (KrSelectionMode::getSelectionHandler()->leftButtonSelects() ||
@@ -629,7 +629,7 @@ void KrBriefView::contentsMousePressEvent( TQMouseEvent * e ) {
 }
 
 void KrBriefView::contentsMouseReleaseEvent( TQMouseEvent * e ) {
-  if (e->button() == Qt::RightButton)
+  if (e->button() == TQt::RightButton)
     contextMenuTimer.stop();
 
   e = transformMouseEvent( e );
@@ -663,11 +663,11 @@ void KrBriefView::contentsMouseMoveEvent ( TQMouseEvent * e ) {
       CANCEL_TWO_CLICK_RENAME;
 
    if ( dragStartPos != TQPoint( -1, -1 ) &&
-        e->state() & Qt::LeftButton && ( dragStartPos - e->pos() ).manhattanLength() > TQApplication::startDragDistance() )
+        e->state() & TQt::LeftButton && ( dragStartPos - e->pos() ).manhattanLength() > TQApplication::startDragDistance() )
       startDrag();
    if (KrSelectionMode::getSelectionHandler()->rightButtonPreservesSelection()
       && KrSelectionMode::getSelectionHandler()->rightButtonSelects()
-      && KrSelectionMode::getSelectionHandler()->showContextMenu() >= 0 && e->state() == Qt::RightButton)
+      && KrSelectionMode::getSelectionHandler()->showContextMenu() >= 0 && e->state() == TQt::RightButton)
       {
          TQIconViewItem *newItem = findItem( e->pos() );
          e->accept();
@@ -1220,7 +1220,7 @@ void KrBriefView::setNameToMakeCurrent( TQIconViewItem * it ) {
 
 void KrBriefView::slotMouseClicked( int button, TQIconViewItem * item, const TQPoint& ) {
    pressedItem = 0; // if the signals are emitted, don't emit twice at contentsMouseReleaseEvent
-   if ( button == Qt::MidButton )
+   if ( button == TQt::MidButton )
       emit middleButtonClicked( dynamic_cast<KrViewItem *>( item ) );
 }
 
@@ -1277,7 +1277,7 @@ bool KrBriefView::eventFilter( TQObject * watched, TQEvent * e )
   }
   else if( watched == header )
   {
-    if( e->type() == TQEvent::MouseButtonPress && ((TQMouseEvent *)e )->button() == Qt::RightButton )
+    if( e->type() == TQEvent::MouseButtonPress && ((TQMouseEvent *)e )->button() == TQt::RightButton )
     {
       setColumnNr();
       return TRUE;
@@ -1295,7 +1295,7 @@ void KrBriefView::makeItemVisible( const KrViewItem *item ) {
 void KrBriefView::initOperator() {
 	_operator = new KrViewOperator(this, this);
 	// TQIconView emits selection changed, so chain them to operator
-	connect(this, TQT_SIGNAL(selectionChanged()), _operator, TQT_SIGNAL(selectionChanged()));
+	connect(this, TQ_SIGNAL(selectionChanged()), _operator, TQ_SIGNAL(selectionChanged()));
 }
 
 void KrBriefView::initProperties() {
