@@ -9,7 +9,7 @@ Queue::~Queue()
 	// TODO: save queue on delete? or just delete jobs
 }
 
-void Queue::enqueue(KIO::Job *job)
+void Queue::enqueue(TDEIO::Job *job)
 {
 	_jobs.append(job);
 	
@@ -18,5 +18,5 @@ void Queue::enqueue(KIO::Job *job)
 
 void Queue::dumpQueue()
 {
-	qDebug("Queue: %s", name().latin1());
+	tqDebug("Queue: %s", name().latin1());
 }
