@@ -49,7 +49,7 @@ struct PredefinedDevice
 
   class SplitterSpinBox : public TQSpinBox
   {
-    Q_OBJECT
+    TQ_OBJECT
     
   private:
     TDEIO::filesize_t division;
@@ -60,7 +60,7 @@ struct PredefinedDevice
     {
       setMaxValue( 0x7FFFFFFF );     /* setting the minimum and maximum values */
       setMinValue( 1 );
-      TQDoubleValidator *dval = new TQDoubleValidator( TQT_TQOBJECT(this) );
+      TQDoubleValidator *dval = new TQDoubleValidator( this );
       setValidator ( dval );
     }
 
@@ -142,7 +142,7 @@ struct PredefinedDevice
 
 class SplitterGUI : TQDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   
 private:
